-- Copyright 2009 Jo-Philipp Wich <jow@openwrt.org>
-- Licensed to the public under the Apache License 2.0.

local fs   = require "nixio.fs"
local nw   = require "luci.model.network"
local fw   = require "luci.model.firewall"
local uci  = require "luci.model.uci".cursor()
local http = require "luci.http"
local sys  = require "luci.sys"

local iw = luci.sys.wifi.getiwinfo(http.formvalue("device"))

local has_firewall = fs.access("/etc/config/firewall")

if not iw then
	luci.http.redirect(luci.dispatcher.build_url("admin/network/wireless"))
	return
end

m = SimpleForm("network", translatef("Joining Network: %q", http.formvalue("join")))
m.cancel = translate("Back to scan results")
m.reset = false

function m.on_cancel()
	local dev = http.formvalue("device")
	http.redirect(luci.dispatcher.build_url(
		dev and "admin/network/wireless_join?device=" .. dev
			or "admin/network/wireless"
	))
end

--字符串分割函数,按空格分割
function lua_string_split(str)

	local arr = {}
	for w in string.gmatch(str, "%S+") do
		table.insert(arr,w)
	end
	return arr
end

nw.init(uci)
fw.init(uci)

m.hidden = {
	device      = http.formvalue("device"),
	join        = http.formvalue("join"),
	channel     = http.formvalue("channel"),
	mode        = http.formvalue("mode"),
	bssid       = http.formvalue("bssid"),
	wep         = http.formvalue("wep"),
	wpa_suites	= http.formvalue("wpa_suites"),
	wpa_version = http.formvalue("wpa_version")
}
--[[
if iw and iw.mbssid_support then
	replace = m:field(Flag, "replace", translate("Replace wireless configuration"),
		translate("Check this option to delete the existing networks from this radio."))

	function replace.cfgvalue() return "0" end
else
	replace = m:field(DummyValue, "replace", translate("Replace wireless configuration"))
	replace.default = translate("The hardware is not multi-SSID capable and the existing " ..
		"configuration will be replaced if you proceed.")

	function replace.formvalue() return "1" end
end
--]]

authmode =  m:field(ListValue, "authmode", translate("授权方式"))
authmode.optional = false
authmode.rmempty = false
authmode:value("WPA2-Personal")
authmode:value("WPA-Personal")
authmode:value("Open System")
-- authmode:default("WPA2-Personal")

encryptype =  m:field(ListValue, "encryptype", translate("WPA 加密"))
encryptype.optional = false
encryptype.rmempty = false
encryptype:value("AES")
encryptype:value("TKIP")
-- encryptype:default("AES")

if http.formvalue("wep") == "1" then
	key = m:field(Value, "key", translate("WEP passphrase"),
		translate("Specify the secret encryption key here."))

	key.password = true
	key.datatype = "wepkey"

elseif (tonumber(m.hidden.wpa_version) or 0) > 0 and
	(m.hidden.wpa_suites == "PSK" or m.hidden.wpa_suites == "PSK2")
then
	key = m:field(Value, "key", translate("WPA passphrase"),
		translate("Specify the secret encryption key here."))

	key.password = true
	key.datatype = "wpakey"
	--m.hidden.wpa_suite = (tonumber(http.formvalue("wpa_version")) or 0) >= 2 and "psk2" or "psk"
end

--[[
newchannel = m:field(Value, "_netchannel_new", translate("目标wifi的channel"),
		translate("请务必确认channel设置与目标wifi的channel相同."))
newchannel.default = m.hidden.channel

newdevice = m:field(Value, "_netdevice_new", translate("device"),
		translate("device."))
newdevice.default = m.hidden.device

newbssid = m:field(Value, "_netbssid_new", translate("bssid"),
		translate("bssid."))
newbssid.default = m.hidden.bssid

newmode = m:field(Value, "_netmode_new", translate("mode"),
		translate("mode."))
newmode.default = m.hidden.mode

newwep = m:field(Value, "_netwep_new", translate("wep"),
		translate("wep."))
newwep.default = m.hidden.wep

newwpa_suites = m:field(Value, "_netwpa_suites_new", translate("wpa_suites"),
		translate("wpa_suites."))
newwpa_suites.default = m.hidden.wpa_suites

newwpa_version = m:field(Value, "_netwpa_version_new", translate("wpa_version"),
		translate("wpa_version."))
newwpa_version.default = m.hidden.wpa_version

newssid = m:field(Value, "_netssid_new", translate("ssid"),
		translate("ssid."))
newssid.default = lua_string_split(m.hidden.join)[2]
--]]
newnet = m:field(Value, "_netname_new", translate("Name of the new network"),
	translate("The allowed characters are: <code>A-Z</code>, <code>a-z</code>, " ..
		"<code>0-9</code> and <code>_</code>"
	))

newnet.default = m.hidden.mode == "Ad-Hoc" and "mesh" or "wwan"
newnet.datatype = "uciname"


function newnet.parse(self, section)
	local net, zone
	
	local ApCliSsid
	local ApCliAuthMode
	local ApCliEncrypType
	local ApCliWPAPSK
	local ApCliChannel
	local ApCliName
	
	ApCliSsid = lua_string_split(m.hidden.join)[2]
	ApCliAuthMode = authmode and authmode:formvalue(section) or ""
	ApCliEncrypType = encryptype and encryptype:formvalue(section) or ""
	ApCliChannel = lua_string_split(m.hidden.join)[1]
	ApCliWPAPSK = key and key:formvalue(section) or ""
	ApCliName = newnet and newnet:formvalue(section) or ""
	if ApCliAuthMode == "WPA2-Personal" then
		ApCliAuthMode = "WPA2PSK"
	elseif ApCliAuthMode == "WPA-Personal" then
		ApCliAuthMode = "WPAPSK"
	elseif ApCliAuthMode == "Open System" then
		ApCliAuthMode = "OPEN"
		ApCliEncrypType = "NONE"
		ApCliWPAPSK = "NONE"
	end
	if m.hidden.device == "mt7615e2" then
		sys.exec("sh /sbin/mtk_wifi_client.sh client_2_4g %s %s %s %s %s %s" %{ApCliSsid, ApCliAuthMode, ApCliEncrypType, ApCliWPAPSK, ApCliChannel, ApCliName})
		
		luci.http.redirect(luci.dispatcher.build_url("admin/network/network"))	
		
	elseif m.hidden.device == "mt7615e5" then
		sys.exec("sh /sbin/mtk_wifi_client.sh client_5g %s %s %s %s %s %s" %{ApCliSsid, ApCliAuthMode, ApCliEncrypType, ApCliWPAPSK, ApCliChannel, ApCliName})
		
		luci.http.redirect(luci.dispatcher.build_url("admin/network/network"))	
	end

end

return m
